@@ -9,13 +9,6 @@ cd ../../../../MediaConch/Project/GNU/CLI
 ./autogen.sh
 cd ../../../..
 
-# Dependencies
-cp -r ~/Documents/almin/libxml2 .
-cp -r ~/Documents/almin/libxslt .
-cp -r ~/Documents/almin/sqlite .
-cp -r ~/Documents/almin/jansson .
-cp -r ~/Documents/almin/libevent .
-
 # libxml2 and libcurl doesn’t like multiarch
 #./CLI_Compile.sh --enable-arch-x86_64 --enable-arch-i386
 ./CLI_Compile.sh
