@@ -17,6 +17,7 @@
 #include "Common/Reports.h"
 #include <Common/MediaConchLib.h>
 #include <ZenLib/ZtringList.h>
+#include <ZenLib/Ztring.h>
 #include <ZenLib/File.h>
 #include <ZenLib/Dir.h>
 
@@ -123,10 +124,10 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
 
     //--------------------------------------------------------------------------
     CLI::CLI() : watch_folder_user(NULL), use_as_user(-1), use_daemon(false), asynchronous(false),
-                 force_analyze(false), mil_analyze(true),
+                 force_analyze(false), full_report(false), include_hidden_files(false), mil_analyze(true),
                  watch_folder_recursive(true), create_policy_mode(false), file_information(false),
                  plugins_list_mode(false), list_watch_folders_mode(false), no_needs_files_mode(false),
-                 list_mode(false)
+                 list_mode(false), fixer(false)
     {
         format = MediaConchLib::format_Max;
     }
@@ -239,6 +240,8 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
                         format = MediaConchLib::format_Html;
                     else if (filename.size() >= 4 && filename.rfind(".csv") == filename.size() - 4)
                         format = MediaConchLib::format_CSV;
+                    else if (filename.size() >= 5 && filename.rfind(".json") == filename.size() - 5)
+                        format = MediaConchLib::format_Json;
                     else
                         format = MediaConchLib::format_Simple;
 
@@ -658,6 +661,8 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
             return set_format(MediaConchLib::format_Simple);
         else if (f == "CSV" || f == "csv")
             return set_format(MediaConchLib::format_CSV);
+        else if (f == "JSON" || f == "json")
+            return set_format(MediaConchLib::format_Json);
         else
             mi_inform = f;
 
@@ -792,6 +797,12 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
         full_report = full;
     }
 
+    //--------------------------------------------------------------------------
+    void CLI::set_include_hidden(bool hidden)
+    {
+        include_hidden_files = hidden;
+    }
+
     //--------------------------------------------------------------------------
     int CLI::add_plugin_to_use(const std::string& plugin)
     {
@@ -907,6 +918,8 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
             f = MediaConchLib::format_Html;
         else if (format == "csv")
             f = MediaConchLib::format_CSV;
+        else if (format == "json")
+            f = MediaConchLib::format_Json;
         else if (format == "simple")
             f = MediaConchLib::format_Simple;
         else
@@ -931,6 +944,23 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
             return CLI_RETURN_FINISH;
         }
 
+        ZenLib::Ztring str = ZenLib::Ztring().From_UTF8(key.c_str());
+        if (str.Compare(__T("File_TryToFix")))
+        {
+            fixer = true;
+            options.push_back(std::make_pair(key, value));
+            options.push_back(std::make_pair("file_parsespeed", "1"));
+        }
+        else if (fixer && (str.Compare(__T("File_ParseSpeed")) || str.Compare(__T("ParseSpeed"))))
+        {
+            ZenLib::Ztring str = ZenLib::Ztring().From_UTF8(value.c_str());
+            if (str != __T("1"))
+            {
+                STRINGOUT(ZenLib::Ztring().From_UTF8("ParseSpeed option must be set to 1 with File_TryToFix option."));
+                return CLI_RETURN_ERROR;
+            }
+        }
+
         options.push_back(std::make_pair(key, value));
         return CLI_RETURN_NONE;
     }
@@ -1043,10 +1073,11 @@ void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_S
             return;
         }
 
-        ZenLib::ZtringList list = ZenLib::Dir::GetAllFileNames(dirname,
-                                                               (ZenLib::Dir::dirlist_t)(ZenLib::Dir::Include_Files |
-                                                                                        ZenLib::Dir::Include_Hidden |
-                                                                                        ZenLib::Dir::Parse_SubDirs));
+        int flags = ZenLib::Dir::Include_Files | ZenLib::Dir::Parse_SubDirs;
+        if (include_hidden_files)
+            flags |= ZenLib::Dir::Include_Hidden;
+
+        ZenLib::ZtringList list = ZenLib::Dir::GetAllFileNames(dirname, (ZenLib::Dir::dirlist_t)flags);
 
         for (size_t i =0; i < list.size(); ++i)
             files.push_back(ZenLib::Ztring(list[i]).To_UTF8()); //Append the filename to the list of filenames to parse
