@@ -116,8 +116,6 @@ void QueueElement::Entry()
             break;
         }
     }
-    if (found == false)
-        MI->Option(__T("ParseSpeed"), __T("0"));
 
     // Configuration of the parsing
     found = false;
@@ -140,7 +138,8 @@ void QueueElement::Entry()
     for (size_t i = 0; i < options.size(); ++i)
         MI->Option(Ztring().From_UTF8(options[i].first), Ztring().From_UTF8(options[i].second));
 
-    MI->Open(ZenLib::Ztring().From_UTF8(file));
+    if(!MI->Open(ZenLib::Ztring().From_UTF8(file)))
+        error = "Unable to open file";
     if (!IsTerminating()) //If terminating was requested, file is partially parsed (and there is some thread lock because the scheduler calls the queue which calls the scheduler) //TODO: reorganize calls
         scheduler->work_finished(this, MI);
     MI_CS.Enter();
@@ -160,6 +159,12 @@ void QueueElement::Entry()
     }
 }
 
+//---------------------------------------------------------------------------
+bool QueueElement::errored()
+{
+    return !error.empty();
+}
+
 //---------------------------------------------------------------------------
 double QueueElement::percent_done()
 {
