@@ -11,6 +11,7 @@
 #include "WebView.h"
 #include "progressbar.h"
 #include <QProgressBar>
+#include <QRegularExpression>
 
 namespace MediaConch {
 
@@ -39,11 +40,10 @@ void PublicPoliciesWindow::display_public_policies()
 //---------------------------------------------------------------------------
 void PublicPoliciesWindow::change_qt_scripts_in_template(QString& html)
 {
-    QRegExp reg("\\{\\{ QT_SCRIPTS \\}\\}");
+    QRegularExpression reg("\\{\\{ QT_SCRIPTS \\}\\}", QRegularExpression::InvertedGreedinessOption);
     QString script;
     int     pos = 0;
 
-    reg.setMinimal(true);
 #if defined(WEB_MACHINE_KIT)
     script += "        <script type=\"text/javascript\" src=\"qrc:/publicPolicies/listWebKit.js\"></script>\n"
               "        <script type=\"text/javascript\" src=\"qrc:/users/userWebKit.js\"></script>\n";
@@ -58,47 +58,40 @@ void PublicPoliciesWindow::change_qt_scripts_in_template(QString& html)
     script += "        <script type=\"text/javascript\" src=\"qrc:/publicPolicies/listPolicyTree.js\"></script>\n";
     script += "        <script type=\"text/javascript\" src=\"qrc:/utils/url.js\"></script>\n";
     script += "        <script type=\"text/javascript\" src=\"qrc:/menu.js\"></script>\n";
-    if ((pos = reg.indexIn(html, pos)) != -1)
-        html.replace(pos, reg.matchedLength(), script);
+    QRegularExpressionMatch match = reg.match(html, pos);
+    if ((pos = match.capturedStart()) != -1)
+        html.replace(pos, match.capturedLength(), script);
 }
 
 //---------------------------------------------------------------------------
 void PublicPoliciesWindow::set_webmachine_script_in_template(QString& html)
 {
-    QRegExp reg("\\{\\{[\\s]+webmachine[\\s]\\}\\}");
+    QRegularExpression reg("\\{\\{[\\s]+webmachine[\\s]\\}\\}", QRegularExpression::InvertedGreedinessOption);
     QString machine;
     int     pos = 0;
 
-    reg.setMinimal(true);
 #if defined(WEB_MACHINE_KIT)
     machine = "WEB_MACHINE_KIT";
 #elif defined(WEB_MACHINE_ENGINE)
     machine = "WEB_MACHINE_ENGINE";
 #endif
-    if ((pos = reg.indexIn(html, pos)) != -1)
-        html.replace(pos, reg.matchedLength(), machine);
+    QRegularExpressionMatch match = reg.match(html, pos);
+    if ((pos = match.capturedStart()) != -1)
+        html.replace(pos, match.capturedLength(), machine);
 }
 
 //---------------------------------------------------------------------------
 void PublicPoliciesWindow::remove_result_in_template(QString& html)
 {
-    QRegExp reg("\\{% block result %\\}\\{% endblock %\\}");
-    int pos = 0;
-
-    reg.setMinimal(true);
-    while ((pos = reg.indexIn(html, pos)) != -1)
-        html.replace(pos, reg.matchedLength(), "");
+    QRegularExpression reg("\\{% block result %\\}\\{% endblock %\\}", QRegularExpression::InvertedGreedinessOption);
+    html.replace(reg, "");
 }
 
 //---------------------------------------------------------------------------
 void PublicPoliciesWindow::change_checker_in_template(const QString& policy, QString& html)
 {
-    QRegExp reg("\\{% block checker %\\}\\{% endblock %\\}");
-    int pos = 0;
-
-    reg.setMinimal(true);
-    while ((pos = reg.indexIn(html, pos)) != -1)
-        html.replace(pos, reg.matchedLength(), policy);
+    QRegularExpression reg("\\{% block checker %\\}\\{% endblock %\\}", QRegularExpression::InvertedGreedinessOption);
+    html.replace(reg, policy);
 }
 
 //---------------------------------------------------------------------------
