@@ -20,30 +20,56 @@ var mediaInfoCell = (function() {
                             <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button> \
                             <h4 class="modal-title">MediaInfo report</h4> \
                         </div> \
+                        <div class="modal-header"> \
+                            <div class="pull-left"> \
+                                <i class="glyphicon glyphicon-search"></i><input type="text" value="" class="jstreeSearch" id="infoSearch-' + fileId + '" placeholder="Search" /> \
+                            </div> \
+                            <div class="pull-right"> \
+                                <button type="button" class="btn btn-warning mi-create-report">Create policy from MediaInfo report</button> \
+                                 <div class="btn-group mi-dld-group"> \
+                                    <button class="btn btn-primary mi-dld">Download MediaInfo report</button> \
+                                    <button class="btn btn-primary dropdown-toggle" data-toggle="dropdown"><span class="caret"></span></button> \
+                                    <ul class="dropdown-menu col-md-12 mi-select-output"> \
+                                    </ul>\
+                                </div> \
+                            </div> \
+                        </div> \
                         <div class="modal-body"> \
                             <div class="row"> \
-                                <div class="col-md-6"> \
-                                    <i class="glyphicon glyphicon-search"></i><input type="text" value="" class="jstreeSearch" id="infoSearch-' + fileId + '" placeholder="Search" /> \
-                                </div> \
                                 <div class="col-md-12"> \
                                     <div id="info-' + fileId + '"></div> \
                                 </div> \
                             </div> \
                         </div> \
-                            <div class="modal-footer"> \
-                                <button type="button" class="btn btn-warning mi-create-report">Create policy from MediaInfo report</button> \
-                                <button type="button" class="btn btn-primary mi-dld">Download MediaInfo report</button> \
-                                <button type="button" class="btn btn-default" data-dismiss="modal">Close</button> \
+                        <div class="modal-footer"> \
+                            <button type="button" class="btn btn-warning mi-create-report">Create policy from MediaInfo report</button> \
+                            <div class="btn-group mi-dld-group dropup"> \
+                                <button class="btn btn-primary mi-dld">Download MediaInfo report</button> \
+                                <button class="btn btn-primary dropdown-toggle" data-toggle="dropdown"><span class="caret"></span></button> \
+                                <ul class="dropdown-menu col-md-12 mi-select-output"> \
+                                </ul> \
                             </div> \
                         </div> \
+                        <div class="modal-footer"> \
+                            <button type="button" class="btn btn-default" data-dismiss="modal">Close</button> \
+                        </div> \
+                        </div> \
                     </div> \
                 </div>');
 
+                checkerAjax.getMediaInfoOutputList(fileId);
                 displayTree(fileId);
 
                 $('#modalInfo-' + fileId + ' .mi-dld').on('click', function(e) {
                     e.preventDefault();
-                    checkerAjax.downloadReportUrl(fileId, 'mi');
+                    checkerAjax.downloadReportUrl(fileId, 'mi', 'MIXML');
+                });
+
+                $('#modalInfo-' + fileId + ' .mi-select-output').on('click', 'li', function(e) {
+                    e.preventDefault();
+                    e.stopPropagation();
+                    var output = e.currentTarget.getAttribute('data-name');
+                    checkerAjax.downloadReportUrl(fileId, 'mi', output);
                 });
 
                 $('#modalInfo-' + fileId + ' .mi-create-report').on('click', function(e) {
@@ -59,6 +85,12 @@ var mediaInfoCell = (function() {
         });
     };
 
+    var updateOutputList = function(outputList, fileId) {
+        for(index in outputList.output) {
+            $('#modalInfo-' + fileId + ' .mi-select-output').append('<li data-name="' + outputList.output[index].name + '"><a href="#">' + outputList.output[index].desc + '</a></li>');
+        }
+    };
+
     var displayTree = function(fileId) {
         // Disable F2 shortcut (rename) in jstree, needs to be done before jstree initialization
         $('#info-' + fileId).on('keydown.jstree', '.jstree-anchor', function(event) {
@@ -160,6 +192,7 @@ var mediaInfoCell = (function() {
     return {
         init: init,
         success: success,
+        updateOutputList: updateOutputList,
         createPolicySuccess: createPolicySuccess,
         createPolicyError: createPolicyError,
         reset: reset,
