@@ -4,20 +4,25 @@ var databaseAjax = (function() {
     }
 
     var loadTree = function() {
-        res = webpage.checker_list();
-        data = JSON.parse(res);
+        var res = webpage.checker_list();
+        var data = JSON.parse(res);
 
+        var success = 0;
         $.each(data.files, function(idx, val) {
-            database.addFile(val);
+            success++;
+            databaseTable.addFile(val);
         });
 
-        if (data.error && data.error.length)
+        if (success > 0) {
+            databaseTable.draw();
+        }
+        else if (data.error && data.error.length)
             mcoMessage.error(data.error);
     }
 
     var addFileChecker = function(id) {
-        res = webpage.add_file_to_checker_again(id);
-        data = JSON.parse(res);
+        var res = webpage.add_file_to_checker_again(id);
+        var data = JSON.parse(res);
 
         if (data.error && data.error.length)
             mcoMessage.error(data.error);
@@ -26,16 +31,16 @@ var databaseAjax = (function() {
     }
 
     var removeFile = function(id) {
-        res = webpage.remove_file_from_db(id);
-        data = JSON.parse(res);
+        var res = webpage.remove_file_from_db(id);
+        var data = JSON.parse(res);
 
         if (data.error && data.error.length)
             mcoMessage.error(data.error);
     }
 
     var removeAllFiles = function() {
-        res = webpage.remove_all_files_from_db();
-        data = JSON.parse(res);
+        var res = webpage.remove_all_files_from_db();
+        var data = JSON.parse(res);
 
         if (data.error && data.error.length)
             mcoMessage.error(data.error);
